# Django Fast Utils

**Official Documentation** - https://tarsil.github.io/django-fast-utils/

---

## Table of Contents

- [About Django Fast Utils](#about-django-fast-utils-drf)
  - [Overview](#overview)
  - [Versions](#supported-django-and-python-versions)
- [Documentation](#documentation)
  - [Installation](#installation)
- [Documentation and Support](#documentation-and-support)
- [License](#license)

---

## About Django Fast Utils

Django Fast Utils is a miscellaneous of common utilities for every new or existing
django projects. From auditing models to database fields and REST framework mixins.

### Overview

#### Supported Django and Python Versions

| Django / Python | 3.7 | 3.8 | 3.9 | 3.10 |
| --------------- | --- | --- | --- | ---- |
| 2.2             | Yes | Yes | Yes | Yes  |
| 3.0             | Yes | Yes | Yes | Yes  |
| 3.1             | Yes | Yes | Yes | Yes  |
| 3.2             | Yes | Yes | Yes | Yes  |
| 4.0             | Yes | Yes | Yes | Yes  |

## Documentation

### Installation

To install django-fast-utils:

```shell
$ pip install django-fast-utils
```

## Documentation and Support

Full documentation for the project is available at https://tarsil.github.io/django-fast-utils/

## License

Copyright (c) 2022-present Tiago Silva and contributors under the [MIT license](https://opensource.org/licenses/MIT).
